@@ -12,7 +12,7 @@ package Pod::InputObjects;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '1.50';  ## Current version of this package
+$VERSION = '1.64';  ## Current version of this package
 require  5.005;    ## requires this Perl version or later
 
 #############################################################################
@@ -35,6 +35,10 @@ Nothing.
 
 =head1 DESCRIPTION
 
+B<NOTE: This module is considered legacy; modern Perl releases (5.18 and
+higher) are going to remove Pod-Parser from core and use L<Pod::Simple>
+for all things POD.>
+
 This module defines some basic input objects used by B<Pod::Parser> when
 reading and parsing POD text from an input source. The following objects
 are defined:
@@ -480,7 +484,7 @@ sub new {
           @_
     };
 
-    ## Initialize contents if they havent been already
+    ## Initialize contents if they haven't been already
     my $ptree = $self->{'-ptree'} || new Pod::ParseTree();
     if ( ref $ptree =~ /^(ARRAY)?$/ ) {
         ## We have an array-ref, or a normal scalar. Pass it as an
