@@ -29,7 +29,7 @@ use vars qw(@ISA %ESCAPES $VERSION);
 # by Pod::Usage.
 @ISA = qw(Pod::Select);
 
-$VERSION = '2.03';
+$VERSION = '2.07';
 
 BEGIN {
    if ($] < 5.006) {
@@ -312,6 +312,7 @@ sub cmd_head2 {
     if ($$self{alt}) {
         $self->output ("\n==   $_   ==\n\n");
     } else {
+        $_ .= "\n" if $$self{loose};
         $self->output (' ' x ($$self{indent} / 2) . $_ . "\n");
     }
 }
@@ -325,6 +326,7 @@ sub cmd_head3 {
     if ($$self{alt}) {
         $self->output ("\n= $_ =\n");
     } else {
+        $_ .= "\n" if $$self{loose};
         $self->output (' ' x ($$self{indent}) . $_ . "\n");
     }
 }
@@ -388,10 +390,14 @@ sub cmd_for {
     my $self = shift;
     local $_ = shift;
     my $line = shift;
-    return unless s/^text\b[ \t]*\n?//;
+    return unless s/^text\b[ \t]*\r?\n?//;
     $self->verbatim ($_, $line);
 }
 
+# just a dummy method for the time being
+sub cmd_encoding {
+  return;
+}
 
 ############################################################################
 # Interior sequences
@@ -483,7 +489,7 @@ sub item {
         my $margin = $$self{MARGIN};
         $$self{MARGIN} = $indent;
         my $output = $self->reformat ($tag);
-        $output =~ s/\n*$/\n/;
+        $output =~ s/[\r\n]*$/\n/;
         $self->output ($output);
         $$self{MARGIN} = $margin;
         $self->output ($self->reformat ($_)) if /\S/;
@@ -512,7 +518,7 @@ sub wrap {
     my $spaces = ' ' x $$self{MARGIN};
     my $width = $$self{width} - $$self{MARGIN};
     while (length > $width) {
-        if (s/^([^\n]{0,$width})\s+// || s/^([^\n]{$width})//) {
+        if (s/^([^\r\n]{0,$width})\s+// || s/^([^\r\n]{$width})//) {
             $output .= $spaces . $1 . "\n";
         } else {
             last;
@@ -533,8 +539,8 @@ sub reformat {
     # munging to support that.  Otherwise, smash all repeated whitespace.
     if ($$self{sentence}) {
         s/ +$//mg;
-        s/\.\n/. \n/g;
-        s/\n/ /g;
+        s/\.\r?\n/. \n/g;
+        s/[\r\n]+/ /g;
         s/   +/  /g;
     } else {
         s/\s+/ /g;
@@ -615,6 +621,10 @@ Pod::PlainText - Convert POD data to formatted ASCII text
 
 =head1 DESCRIPTION
 
+B<NOTE: This module is considered legacy; modern Perl releases (5.18 and
+higher) are going to remove Pod-Parser from core and use L<Pod::Simple>
+for all things POD.>
+
 Pod::PlainText is a module that can convert documentation in the POD format (the
 preferred language for documenting Perl) into formatted ASCII.  It uses no
 special formatting controls or codes whatsoever, and its output is therefore
@@ -643,12 +653,11 @@ C<=over> blocks.  Defaults to 4.
 
 =item loose
 
-If set to a true value, a blank line is printed after a C<=head1> heading.
-If set to false (the default), no blank line is printed after C<=head1>,
-although one is still printed after C<=head2>.  This is the default because
-it's the expected formatting for manual pages; if you're formatting
-arbitrary text documents, setting this to true may result in more pleasing
-output.
+If set to a true value, a blank line is printed after a C<=headN> headings.
+If set to false (the default), no blank line is printed after C<=headN>.
+This is the default because it's the expected formatting for manual pages;
+if you're formatting arbitrary text documents, setting this to true may
+result in more pleasing output.
 
 =item sentence
 
@@ -722,6 +731,8 @@ subclass of it does.  Look for L<Pod::Text::Termcap|Pod::Text::Termcap>.
 
 =head1 SEE ALSO
 
+B<Pod::PlainText> is part of the L<Pod::Parser> distribution.
+
 L<Pod::Parser|Pod::Parser>, L<Pod::Text::Termcap|Pod::Text::Termcap>,
 pod2text(1)
 
